@@ -1,10 +1,14 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from multidecoder.decoders.concat import STRING_RE
 from multidecoder.hit import find_and_deobfuscate
-from multidecoder.node import Node
 from multidecoder.registry import decoder
 
+if TYPE_CHECKING:
+    from multidecoder.node import Node
+
 REVERSE_RE = rb"(?i)reversed?\(\s*(" + STRING_RE + rb")\s*\)"
 
 
